<?php

namespace App\Http\Controllers\AdminDashboard;
use App\Http\Controllers\Controller;
use App\Models\Blog;

use App\Models\OpenGraph;
use App\Models\Pages;
use Illuminate\Http\Request;

use App\Http\Requests;

class BlogController extends Controller

{
    public function __construct()
    {
        $this->middleware('auth');
    }
    public function index(){
        $blogs=Blog::all();
        //dd(Blog::first()->image->name);
        return view("dashboard.blog.index")->with("blogs",$blogs);
    }
    public function create(){
        return view("dashboard.blog.add");
    }
    public function store(Request $request){
        $request->validate([
            'title_en' => 'required',
            'url'=>'unique:blog,url',
            'body_en' => 'required',
            'image_id' => 'image|mimes:jpeg,png',
            'alt_en' => 'required',
            'title_ar' => 'required',
            'body_ar' => 'required',
            //'alt_ar'=>'required',
        ]);
        $url=$request->url==null?str_slug($request->title_en,'-'):$request->url;
        if ($request->image_id) {
            $image_name = time() . "_" . $request->image_id->getClientOriginalName();
            $request->image_id->storeAs("/storage/uploads/blog", $image_name);

            $image_id = \App\Models\Images::create(['name' => $image_name, 'dir_name' => 'blog', 'alt' => $request->alt_en])->id;
            \App\Models\Arabic\Images::create(['image_id' => $image_id, "alt" => '']);
            \App\Models\English\Images::create(['image_id' => $image_id, "alt" => '']);

            //---------- SEO --------------------
            //------open graph ---------
            $og=OpenGraph::create(['og_image_id'=>$image_id,'og_title'=>$request->title_en,'og_description'=>$request->body_en,
                'og_url'=>$url,'og_type'=>$request->image_id->getClientOriginalExtension(),'created_by'=>auth()->user()->id
            ]);
            //----------------------

            //------------ page -----------
            $page=Pages::create(['is_main_page'=>null,'description'=>$request->body_en,'url'=>$url,
                'name'=>$request->title_en,'og_id'=>$og->id,'created_by'=>auth()->user()->id
            ]);
            //-------------------
            //-----end SEO-----------
            //-----blog ---------
            $blog_id = Blog::create(['url' => $url, 'image_id' => $image_id,'og_id' => $og->id,'page_id' => $page->id,'created_by' => auth()->user()->id])->id;
            \App\Models\Arabic\Blog::create(['blog_id' => $blog_id, 'title' => $request->title_ar, 'blog_body' => $request->body_ar, "alt" => '']);
            \App\Models\English\Blog::create(['blog_id' => $blog_id, 'title' => $request->title_en, 'blog_body' => $request->body_en, "alt" => '']);
            //-------------------------
        }

        return redirect("/adminDashboard/blog");
    }

    public function destroy($id){
        $blog=Blog::find($id);
        $blog->delete();
        return redirect("/adminDashboard/blog");
    }
    public function edit($id){
        $blog=Blog::find($id);
        return view("dashboard.blog.edit")->with("blog",$blog);
    }

    public function update(Request $request,$id){
        $blog = Blog::find($id);
        $request->validate([
            'title_en' => 'required',
            'url'=>'unique:blog,url,'.$id,
            'body_en' => 'required',
            'image_id' => 'image|mimes:jpeg,png',
            'alt_en' => 'required',
            'title_ar' => 'required',
            'body_ar' => 'required',
            //'alt_ar'=>'required',
        ]);
        $url=$request->url==null?str_slug($request->title_en,'-'):$request->url;
        if ($request->image_id) {
            $image_path = public_path("/storage/uploads/blog/" . $blog->image->name);
            if (\File::exists($image_path)) {
                unlink($image_path);
            } else {
            }
            $image_name = time() . "_" . $request->image_id->getClientOriginalName();
            $request->image_id->storeAs("/storage/uploads/blog", $image_name);
            \App\Models\Images::where('id', $blog->image_id)->update(['name' => $image_name, 'dir_name' => 'blog', 'alt' => $request->alt_en]);
            \App\Models\Arabic\Images::where('image_id', $blog->image_id)->update(["alt" => '']);
            \App\Models\English\Images::where('image_id', $blog->image_id)->update(["alt" => '']);
        } else {
            \App\Models\Images::where('id', $blog->image_id)->update(['alt' => $request->alt_en]);
        }
        $blog->update(['url' => $url, 'created_by' => auth()->user()->id]);
        OpenGraph::where('id',$blog->og_id)->update(['og_url'=>$url]);
        Pages::where('id',$blog->page_id)->update(['url'=>$url]);
        \App\Models\Arabic\Blog::where('blog_id', $id)->update(['title' => $request->title_ar, 'blog_body' => $request->body_ar, "alt" => '']);
        \App\Models\English\Blog::where('blog_id', $id)->update(['title' => $request->title_en, 'blog_body' => $request->body_en, "alt" => '']);

        return redirect("/adminDashboard/blog");

    }
}
